@@ -1,9 +1,11 @@
-import sys
 import json
 import subprocess
+import sys
+
+from click._compat import WIN
 
 
-IMPORT_TEST = b'''\
+IMPORT_TEST = b"""\
 try:
     import __builtin__ as builtins
 except ImportError:
@@ -25,26 +27,46 @@ import click
 rv = list(found_imports)
 import json
 click.echo(json.dumps(rv))
-'''
+"""
 
-ALLOWED_IMPORTS = set([
-    'weakref', 'os', 'struct', 'collections', 'sys', 'contextlib',
-    'functools', 'stat', 're', 'codecs', 'inspect', 'itertools', 'io',
-    'threading'
-])
+ALLOWED_IMPORTS = {
+    "weakref",
+    "os",
+    "struct",
+    "collections",
+    "sys",
+    "contextlib",
+    "functools",
+    "stat",
+    "re",
+    "codecs",
+    "inspect",
+    "itertools",
+    "io",
+    "threading",
+    "colorama",
+    "errno",
+    "fcntl",
+    "datetime",
+    "pipes",
+    "shlex",
+}
+
+if WIN:
+    ALLOWED_IMPORTS.update(["ctypes", "ctypes.wintypes", "msvcrt", "time", "zlib"])
 
 
 def test_light_imports():
-    c = subprocess.Popen([sys.executable, '-'], stdin=subprocess.PIPE,
-                         stdout=subprocess.PIPE)
+    c = subprocess.Popen(
+        [sys.executable, "-"], stdin=subprocess.PIPE, stdout=subprocess.PIPE
+    )
     rv = c.communicate(IMPORT_TEST)[0]
 
     if sys.version_info[0] != 2:
-        rv = rv.decode('utf-8')
+        rv = rv.decode("utf-8")
     imported = json.loads(rv)
-    print(imported)
 
     for module in imported:
-        if module == 'click' or module.startswith('click.'):
+        if module == "click" or module.startswith("click."):
             continue
         assert module in ALLOWED_IMPORTS
